/*
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA  02110-1301, USA.

    ---
    Copyright (C) 2008, Hasan Abdel Halim  <hasana@gmail.com>
 */

#include "plasma-mpclient.h"
//QT
#include <QDBusInterface>

//Plasma
#include <plasma/theme.h>
#include <plasma/containment.h>
#include <plasma/widgets/label.h>
#include <plasma/widgets/icon.h>
#include <plasma/widgets/pushbutton.h>
#include <plasma/widgets/lineedit.h>
#include <plasma/layouts/vboxlayout.h>
#include <plasma/layouts/hboxlayout.h>

MPClient::MPClient(QObject *parent, const QVariantList &args)
    :Plasma::Applet(parent, args)
{
//     setDrawStandardBackground(true);
   setMinimumContentSize(140, 80);
}

void MPClient::init(){

    Plasma::HBoxLayout *btns_layout = new Plasma::HBoxLayout(this);
    btns_layout->setMargin(0);
    btns_layout->setSpacing(0);

    Plasma::Icon *icon_play = new Plasma::Icon(KIcon("media-playback-start"), "", this);
    Plasma::Icon *icon_stop = new Plasma::Icon(KIcon("media-playback-stop"), "", this);
    Plasma::Icon *icon_next = new Plasma::Icon(KIcon("media-skip-forward"), "", this);
    Plasma::Icon *icon_prev = new Plasma::Icon(KIcon("media-skip-backward"), "", this);

    btns_layout->addItem(icon_prev);
    btns_layout->addItem(icon_play);
    btns_layout->addItem(icon_stop);
    btns_layout->addItem(icon_next);

    connect(icon_prev, SIGNAL(clicked()), this, SLOT(slotPrev()));
    connect(icon_play, SIGNAL(clicked()), this, SLOT(slotPlay()));
    connect(icon_stop, SIGNAL(clicked()), this, SLOT(slotStop()));
    connect(icon_next, SIGNAL(clicked()), this, SLOT(slotNext()));

    Plasma::VBoxLayout *main_layout = new Plasma::VBoxLayout(this);
    main_layout->setMargin(0);
    main_layout->setSpacing(0);

    bool isOnDesktop = (containment()->containmentType()==Plasma::Containment::DesktopContainment);
    if (isOnDesktop)
    {
        Plasma::LineEdit *label_title = new Plasma::LineEdit(this);
//         label_title->setEnabled(false);
        label_title->setStyled(false);
        label_title->setHtml("<center><strong>"+ i18n("MPClient") + "</strong></center><br/>");
        label_title->setDefaultTextColor(Plasma::Theme::self()->textColor());
        label_title->setTextWidth(contentSize().width());
        label_title->update();
        main_layout->addItem(label_title);
    }

    main_layout->addItem(btns_layout);
    main_layout->setGeometry(QRectF(0,0, contentSize().width(), contentSize().height()));
    // update();
    //updateGeometry();
}

MPClient::~MPClient()
{
}

// QSizeF MPClient::contentSizeHint() const
// {
// }

void MPClient::constraintsUpdated(Plasma::Constraints constraints)
{
//     Q_UNUSED(constraints)
    if (constraints & Plasma::FormFactorConstraint) {
        if (formFactor() == Plasma::Planar ||
            formFactor() == Plasma::MediaCenter) {
      //Desktop
           // setMinimumContentSize(200, 200);make
            } else {
    // Panel
//                 setDrawStandardBackground(false);
                //m_lblTitle->setVisible(false);
                setMinimumContentSize(100, 16);
    //            updateGeometry();
            }
//             updateGeometry();
    }
    if (constraints & Plasma::SizeConstraint) {
        //m_icon->resize(contentSize());
        //m_lblTitle->setTextWidth(contentSize().width());
        //m_lblTitle->update();
    }
}
Qt::Orientations MPClient::expandingDirections() const
{
    return Qt::Vertical;
}

void MPClient::slotPrev()
{
    QDBusInterface KLauncherApp("org.kde.klauncher", "/");
    KLauncherApp.call("exec_blind", QString("mpc"), QStringList() <<  "prev");
}

void MPClient::slotPlay()
{
    QDBusInterface KLauncherApp("org.kde.klauncher", "/");
    KLauncherApp.call("exec_blind", QString("mpc"), QStringList() <<  "play");
}

void MPClient::slotStop()
{
    QDBusInterface KLauncherApp("org.kde.klauncher", "/");
    KLauncherApp.call("exec_blind", QString("mpc"), QStringList() <<  "stop");
}

void MPClient::slotNext()
{
    QDBusInterface KLauncherApp("org.kde.klauncher", "/");
    KLauncherApp.call("exec_blind", QString("mpc"), QStringList() <<  "next");
}

void MPClient::paintInterface(QPainter *p,
                                       const QStyleOptionGraphicsItem *option, const QRect &contentsRect)
{
    Q_UNUSED(option)
    Q_UNUSED(p)
    Q_UNUSED(contentsRect)
}

#include "plasma-mpclient.moc"
